<?php declare(strict_types=1);

namespace App\Form;

use Symfony\Component\Form\{
	AbstractType, Extension\Core\Type\ChoiceType, FormBuilderInterface
};
use Symfony\Component\OptionsResolver\Exception\AccessException;
use Symfony\Component\OptionsResolver\OptionsResolver;

use App\Entity\Lenses;

class LensesType extends AbstractType
{
	/**
	 * {@inheritdoc}
	 */
	public function buildForm(FormBuilderInterface $builder, array $options): void
	{
		$builder->add('brand')
			->add('coatings')
			->add('productLine')
			->add('model')
			->add('mount')
			->add('imageSize', ChoiceType::class, [
				'choices' => [
					'Small Format' => [
						'35mm' => '35mm',
						'APS-C' => 'APS-C',
						'Micro 4/3' => 'Micro 4/3',
					],
					'Medium Format' => [
						'6x6' => '6x6cm',
						'6x4.5' => '6x4.5cm',
						'4x4' => '4x4cm',
					]
				]
			])
			->add('minFStop')
			->add('maxFStop')
			->add('minFocalLength')
			->add('maxFocalLength')
			->add('serial')
			->add('purchasePrice')
			->add('notes')
			->add('received')
			->add('formerlyOwned')
			->add('frontFilterSize')
			->add('rearFilterSize')
			->add('isTeleconverter')
			->add('designElements')
			->add('designGroups')
			->add('apertureBlades');
	}

	/**
	 * {@inheritdoc}
	 * @throws AccessException
	 */
	public function configureOptions(OptionsResolver $resolver): void
	{
		$resolver->setDefaults(array(
			'data_class' => Lenses::class
		));
	}

	/**
	 * {@inheritdoc}
	 */
	public function getBlockPrefix(): string
	{
		return 'camerabundle_lenses';
	}
}
